LoadingController class

Constructors

LoadingController({required BuildContext context, bool allowDismiss = false, String tapAlertText = "Long press to dismiss"})

Properties

allowDismiss bool
getter/setter pair
context BuildContext
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onDismiss ↔ dynamic Function()?
getter/setter pair
onForceClose ↔ dynamic Function()?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tapAlertText String
getter/setter pair

Methods

dismiss() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEvent({dynamic onForceClose()?, dynamic onDismiss()?}) → dynamic
show(Widget dialog, {int timeOut = 45}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited